<?php

namespace Drupal\project_browser_gitlab\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Deriver for Project Browser Gitlab source plugins.
 */
class GitlabDeriver extends DeriverBase implements ContainerDeriverInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * Constructor for the deriver.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *  The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $sources = $this->entityTypeManager->getStorage('project_browser_gitlab_source')->loadMultiple();

    foreach ($sources ?? [] as $source) {
      $this->derivatives[$source->id()] = [
        'id' => $source->id(),
        'label' => $source->label(),
        'description' => $source->domain() . $source->group(),
        'local_task' => [
          'title' => $source->label(),
        ]
      ] + $base_plugin_definition;
    }

    return $this->derivatives;
  }

}
